mod raw_audio;
mod xa_audio;

use clap::{Args, ValueEnum};
use std::io::Write;
use tool_helper::{Error, Input};

#[derive(Args)]
pub struct Arguments {
    #[clap(value_enum, value_parser, default_value_t=Frequency::High)]
    frequency:    Frequency,
    #[clap(value_enum, value_parser, default_value_t=Channels::Stereo)]
    channels:     Channels,
    #[clap(value_enum, value_parser, default_value_t=SampleDepth::Normal)]
    sample_depth: SampleDepth,
}

#[derive(Copy, Clone, ValueEnum)]
pub enum Frequency {
    High,
    Low,
}

#[derive(Copy, Clone, ValueEnum)]
pub enum Channels {
    Stereo,
    Mono,
}

#[derive(Copy, Clone, ValueEnum)]
pub enum SampleDepth {
    Normal,
    High
}

pub fn convert(args: Arguments, input: Input, output: &mut dyn Write) -> Result<(), Error> {
    let prepared_xa_audio = raw_audio::load_as_i16_audio(input, xa_audio::audio_conversion_settings(&args))?;
    xa_audio::convert(prepared_xa_audio, output, &args)
}